@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   nomad.cpp
  \brief  NOMAD main file
@@ -48,31 +50,32 @@
 #include "nomad.hpp"
 
 /* *************************  snomadr  zhenghua *********************** */
+/* please include "nomad.hpp" firstly. */
 #include <R.h>   
 #include <Rdefines.h>
 #include <R_ext/Utils.h>
 
 namespace NOMAD {
-
 /* *************************  snomadr  zhenghua *********************** */
-class Routbuf: public std::streambuf {
-		private:
-				int overflow(int c){
+  class Routbuf: public std::streambuf {
+  private:
+    int overflow(int c){
 #ifdef R_VERSION
-								if(c!=EOF) Rprintf("%.1s", (char *)&c);  //this is for the class Display in NOMAD. cout will be redirected to this class and output by Rprintf.
+      if(c!=EOF) Rprintf("%.1s", (char *)&c);  //this is for the class Display in NOMAD. cout will be redirected to this class and output by Rprintf.
 #else
-								if(c!=EOF) Rprintf("%.1s", (char *)&c);  //this is for the class Display in NOMAD. cout will be redirected to this class and output by Rprintf.
+      if(c!=EOF) Rprintf("%.1s", (char *)&c);  //this is for the class Display in NOMAD. cout will be redirected to this class and output by Rprintf.
 #endif
-								return c;
-				}
+      return c;
+    }
 
-};
+  };
 
-Routbuf routbuf;
-std::ostream rout(&routbuf);
+  Routbuf routbuf;
+  std::ostream rout(&routbuf);
 }
 
-/* *************************  snomadr  zhenghua *********************** */
+
+
 
 
 /*------------------------------------------*/
@@ -94,18 +97,17 @@ int main ( int argc , char ** argv )
         // usage:
         if ( argc < 2 )
         {
-            NOMAD::display_usage ( argv[0],NOMAD::rout );  //zhenghua
+	  NOMAD::display_usage ( argv[0],NOMAD::rout );   //zhenghua
             NOMAD::end();
             return EXIT_FAILURE;
         }
         
         // parameters file:
-        std::string param_file_name = argv[1];
-        std::string opt             = param_file_name;
+        std::string opt             = argv[1];
         NOMAD::toupper ( opt );
         
-        // display version if option '-v' has been specified:
-        if ( opt == "-U" )
+        // display usage if option '-u' has been specified:
+        if ( opt == "-U" || opt == "-USAGE" || opt == "--USAGE" )
         {
             NOMAD::display_usage ( argv[0], out );
             NOMAD::end();
@@ -114,7 +116,7 @@ int main ( int argc , char ** argv )
         
         
         // display version if option '-v' has been specified:
-        if ( opt == "-V" || opt =="-VERSION")
+        if ( opt == "-V" || opt == "-VERSION" || opt == "--VERSION" )
         {
             NOMAD::display_version ( out );
             NOMAD::end();
@@ -122,7 +124,7 @@ int main ( int argc , char ** argv )
         }
         
         // display info if option '-i' has been specified:
-        if ( opt == "-I" || opt == "-INFO" )
+        if ( opt == "-I" || opt == "-INFO" || opt == "--INFO" )
         {
             NOMAD::display_info  ( out );
             NOMAD::display_usage ( argv[0], out );
@@ -134,7 +136,7 @@ int main ( int argc , char ** argv )
         NOMAD::Parameters p ( out );
         
         // display help on parameters if option '-h' has been specified:
-        if ( opt == "-H" || opt == "-HELP" )
+        if ( opt == "-H" || opt == "-HELP" || opt == "--HELP" )
         {
             p.help ( argc , argv );
             NOMAD::end();
@@ -142,32 +144,53 @@ int main ( int argc , char ** argv )
         }
         
         // display developer help on parameters if option '-d' has been specified:
-        if ( opt == "-D" )
+        if ( opt == "-D" || opt == "-DEVELOPER" || opt == "--DEVELOPER" )
         {
             p.help ( argc , argv,true );
             NOMAD::end();
             return EXIT_SUCCESS;
         }
         
+        if ( opt[0] == '-' )
+        {
+            // Unrecognized flag. Display usage and exit gracefully.
+            error = std::string("ERROR: Unrecognized option ") + argv[1];
+            NOMAD::rout << std::endl << error << std::endl << std::endl;
+            NOMAD::display_usage ( argv[0], out );
+            NOMAD::end();
+            return EXIT_FAILURE;
+        }
+
+        std::string param_file_name = argv[1];
+
+        // Verify the argument is a file name 
+        if ( !NOMAD::check_read_file(param_file_name) )
+        {
+            // Could not read input file. Display usage and exit gracefully.
+            error = std::string("ERROR: Could not read file \"") + argv[1] + "\"";
+            NOMAD::rout << std::endl << error << std::endl << std::endl;
+            NOMAD::display_usage ( argv[0], out );
+            NOMAD::end();
+            return EXIT_FAILURE;
+        }
         
         // check the number of processess:
 #ifdef USE_MPI
         if ( NOMAD::Slave::get_nb_processes() < 2 )
         {
-            NOMAD::rout << "ERROR: Incorrect command to run with MPI." << std::endl; //zhenghua
-            NOMAD::display_usage ( argv[0], NOMAD::rout );   //zhenghua
+            error = std::string("ERROR: Incorrect command to run with MPI.");
+            NOMAD::rout << std::endl << error << std::endl << std::endl;
+            NOMAD::display_usage ( argv[0], NOMAD::rout );
             NOMAD::end();
             return EXIT_FAILURE;
         }
 #endif
         
         try {
-            
-            
+
             // read parameters file:
             p.read ( param_file_name );
             
-           
             // parameters check:
             p.check();
             
@@ -200,8 +223,8 @@ int main ( int argc , char ** argv )
         {
             if ( NOMAD::Slave::is_master() )
             {
-                error = std::string ( "NOMAD has been interrupted: " ) + e.what();
-                NOMAD::rout << std::endl << error << std::endl << std::endl;  //zhenghua
+                error = std::string ( "ERROR: " ) + e.what();
+                NOMAD::rout << std::endl << error << std::endl << std::endl;
             }
         }
         
@@ -326,19 +349,23 @@ void NOMAD::display_info ( const NOMAD::Display & out )
     out << std::endl << "NOMAD - version "
     << NOMAD::VERSION
     << NOMAD::open_block(" has been created by")
-    << "Charles Audet        - Ecole Polytechnique de Montreal" << std::endl
-    << "Sebastien Le Digabel - Ecole Polytechnique de Montreal" << std::endl
-    << "Christophe Tribes    - Ecole Polytechnique de Montreal" << std::endl
+    << "Charles Audet               - Ecole Polytechnique de Montreal" << std::endl
+    << "Sebastien Le Digabel        - Ecole Polytechnique de Montreal" << std::endl
+    << "Viviane Rochon Montplaisir  - Ecole Polytechnique de Montreal" << std::endl
+    << "Christophe Tribes           - Ecole Polytechnique de Montreal" << std::endl
     << NOMAD::close_block()
     << std::endl
     << "The copyright of NOMAD - version "
     << NOMAD::VERSION
     << NOMAD::open_block(" is owned by")
-    << "Sebastien Le Digabel - Ecole Polytechnique de Montreal" << std::endl
-    << "Christophe Tribes    - Ecole Polytechnique de Montreal" << std::endl
+    << "Sebastien Le Digabel        - Ecole Polytechnique de Montreal" << std::endl
+    << "Viviane Rochon Montplaisir  - Ecole Polytechnique de Montreal" << std::endl
+    << "Christophe Tribes           - Ecole Polytechnique de Montreal" << std::endl
     << NOMAD::close_block()
-    << std::endl << "NOMAD version 3 is a new version of NOMAD v1 and v2, it has been funded by AFOSR and Exxon Mobil." << std::endl
-    << "NOMAD v1 and v2 were created and developed by Mark Abramson, Charles Audet, Gilles Couture and John Dennis Jr., and were funded by AFOSR and Exxon Mobil." << std::endl
+    << std::endl << "NOMAD version 3 is a new version of Nomad v1 and v2, it has been funded by AFOSR and Exxon Mobil." << std::endl
+    << "Nomad v1 and v2 were created and developed by Mark A. Abramson from The Boeing Company, Charles Audet " << std::endl
+    << " and Gilles Couture from Ecole Polytechnique de Montreal, and John E. Dennis Jr. from Rice University," << std::endl
+    << " and were funded by AFOSR and Exxon Mobil." << std::endl
     << std::endl
     << "Download  : www.gerad.ca/nomad" << std::endl
     << "License   : \'" << NOMAD::LGPL_FILE       << "\'" << std::endl
